==> kwin-5.22.5-x86_64-2.txz: usr/lib64/cmake/KWinEffects/KWinEffectsTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KWinEffects::kwinxrenderutils" for configuration "Release"
set_property(TARGET KWinEffects::kwinxrenderutils APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KWinEffects::kwinxrenderutils PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libkwinxrenderutils.so.5.22.5"
  IMPORTED_SONAME_RELEASE "libkwinxrenderutils.so.13"
  )

list(APPEND _IMPORT_CHECK_TARGETS KWinEffects::kwinxrenderutils )
list(APPEND _IMPORT_CHECK_FILES_FOR_KWinEffects::kwinxrenderutils "${_IMPORT_PREFIX}/lib64/libkwinxrenderutils.so.5.22.5" )

# Import target "KWinEffects::kwineffects" for configuration "Release"
set_property(TARGET KWinEffects::kwineffects APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KWinEffects::kwineffects PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::Declarative;KWinEffects::kwinglutils;KWinEffects::kwinxrenderutils"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libkwineffects.so.5.22.5"
  IMPORTED_SONAME_RELEASE "libkwineffects.so.13"
  )

list(APPEND _IMPORT_CHECK_TARGETS KWinEffects::kwineffects )
list(APPEND _IMPORT_CHECK_FILES_FOR_KWinEffects::kwineffects "${_IMPORT_PREFIX}/lib64/libkwineffects.so.5.22.5" )

# Import target "KWinEffects::kwinglutils" for configuration "Release"
set_property(TARGET KWinEffects::kwinglutils APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KWinEffects::kwinglutils PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libkwinglutils.so.5.22.5"
  IMPORTED_SONAME_RELEASE "libkwinglutils.so.13"
  )

list(APPEND _IMPORT_CHECK_TARGETS KWinEffects::kwinglutils )
list(APPEND _IMPORT_CHECK_FILES_FOR_KWinEffects::kwinglutils "${_IMPORT_PREFIX}/lib64/libkwinglutils.so.5.22.5" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> kwin-5.23.1-x86_64-1.txz: usr/lib64/cmake/KWinEffects/KWinEffectsTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KWinEffects::kwinxrenderutils" for configuration "Release"
set_property(TARGET KWinEffects::kwinxrenderutils APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KWinEffects::kwinxrenderutils PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libkwinxrenderutils.so.5.23.1"
  IMPORTED_SONAME_RELEASE "libkwinxrenderutils.so.13"
  )

list(APPEND _IMPORT_CHECK_TARGETS KWinEffects::kwinxrenderutils )
list(APPEND _IMPORT_CHECK_FILES_FOR_KWinEffects::kwinxrenderutils "${_IMPORT_PREFIX}/lib64/libkwinxrenderutils.so.5.23.1" )

# Import target "KWinEffects::kwineffects" for configuration "Release"
set_property(TARGET KWinEffects::kwineffects APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KWinEffects::kwineffects PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::Declarative;KWinEffects::kwinglutils"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libkwineffects.so.5.23.1"
  IMPORTED_SONAME_RELEASE "libkwineffects.so.13"
  )

list(APPEND _IMPORT_CHECK_TARGETS KWinEffects::kwineffects )
list(APPEND _IMPORT_CHECK_FILES_FOR_KWinEffects::kwineffects "${_IMPORT_PREFIX}/lib64/libkwineffects.so.5.23.1" )

# Import target "KWinEffects::kwinglutils" for configuration "Release"
set_property(TARGET KWinEffects::kwinglutils APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KWinEffects::kwinglutils PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libkwinglutils.so.5.23.1"
  IMPORTED_SONAME_RELEASE "libkwinglutils.so.13"
  )

list(APPEND _IMPORT_CHECK_TARGETS KWinEffects::kwinglutils )
list(APPEND _IMPORT_CHECK_FILES_FOR_KWinEffects::kwinglutils "${_IMPORT_PREFIX}/lib64/libkwinglutils.so.5.23.1" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
